<?php

namespace Drupal\tsk\Services;

use Drupal\Core\KeyValueStore\KeyValueExpirableFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides methods to delete temporary storages.
 *
 * @package Drupal\tsk
 */
class TskService implements TskServiceInterface {

  /**
   * The storage factory creating the backend to store the data.
   *
   * @var \Drupal\Core\KeyValueStore\KeyValueExpirableFactoryInterface
   */
  protected $storageFactory;

  /**
   * Constructs a TskService object.
   *
   * @param \Drupal\Core\KeyValueStore\KeyValueExpirableFactoryInterface $storage_factory
   *   The key/value store factory.
   */
  public function __construct(KeyValueExpirableFactoryInterface $storage_factory) {
    $this->storageFactory = $storage_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('keyvalue.expirable')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function kill(string $collection, string $type = 'private', bool $kill_all = TRUE, string $key = ''): void {

    $storage = $this->storageFactory->get("tempstore.$type.$collection");

    if ($kill_all) {
      $storage->deleteAll();
    }
    else {
      $storage->delete($key);
    }
  }

}
